---
layout: default
---

*A highly efficient implementation of Q-Exponential Processes in [PyTorch](https://pytorch.org) based on [GPyTorch](https://gpytorch.ai).*

* * *

# Example

Check out the [`examples`](https://github.com/lanzithinking/QePyTorch/tree/main/examples).

# Documentation

Here is the [`documentation`](https://qepytorch.readthedocs.io/en/stable/).

* * *

# Installation

## pip

```
pip install qpytorch
```

## conda

```
conda install -c conda-forge qpytorch
```

## from source

```
git clone https://github.com/lanzithinking/qepytorch.git
cd qepytorch
conda env create -f env_install.yaml
```

* * *

# Team

* Maintain: [Shiwei Lan](https://math.la.asu.edu/~slan) (Arizona State University)
* Contribute: Shuyi Li, Guangting Yu, Zhi Chang, Chukwudi Paul Obite, Keyan Wu, and many more!

# Citing Us

> [Li, Shuyi, Michael O'Connor, and Shiwei Lan. "Bayesian Learning via Q-Exponential Process." In Advances in Neural Information Processing Systems (2023).](https://papers.nips.cc/paper_files/paper/2023/hash/e6bfdd58f1326ff821a1b92743963bdf-Abstract-Conference.html)

```
@inproceedings{li2023QEP,
  title={Bayesian Learning via Q-Exponential Process},
  author={Li, Shuyi, Michael O'Connor, and Shiwei Lan},
  booktitle={Advances in Neural Information Processing Systems},
  year={2023}
}
```